# Far right filter

## The issue

Has an user and an admin I don't want far right content to be displayed in my pod.

Has a Funkwhale community following this [code of conduct](https://www.funkwhale.audio/code-of-conduct/) I don't want my software to be used to listen to music going against our principles.

## The solution

Hard code a filter against far right artists preventing far right movement to use the software, our builds and resources to promote their ideology.

## Feature behavior

To find a common consensus/definition of far right ideology we will use wikidata. Moderation and debates can happen on their infrastructure. To be transparent about why an artist in being censored, the backend should display the reference of the wikidata object being used to classify the artist has a far right defender. This way users can go the the related wikidata page to check the reference if needed.

### Backend behavior

### Backend

- [x] a celery tasks that add far_right artists to the db, or update existing artist with the far_right attribute if the name matches. Launched every month.
- [x] a cli tool to display the list of right wing artists that display the name, the mbid and the wikidata ref. Prompt a warning if mbid is missing so admins can add a mbid `docker compose run --rm api funkwhale-manage wikidata_far_right`
- [x] A new artist attribute `far_right` displaying the wikidata id
- [ ] Display an explicit api error response that explain why the artist in banned (link the funkwhale code of conduct and the artist wikidata id):
  - [x] on the import process : display an explicit error during import
  - [ ] on the federation artist serializers

workflow : querying wikidata -> create or update artist entries with the new `far_right` attribute -> filter out the artist based on the attribute and display logging info explaining why

#### Wikidata query

```
SELECT DISTINCT ?item ?itemLabel WHERE {
  SERVICE wikibase:label { bd:serviceParam wikibase:language "[AUTO_LANGUAGE]". }

  ?item wdt:P31 wd:Q215380.
  # Match items with the relevant properties and ensure they have references
  {
    VALUES ?genre {
      wd:Q533914        # NSBM
      wd:Q224694        # whit power music
      wd:Q113084468     # nazi rock
      wd:Q121411631     # neonazi music
      wd:Q1547998       # rock identitaire francai
      wd:Q602498        # nazi punk
      wd:Q3328582       # italian right wing alternative
      wd:Q828181        # rock against communism
    }

    ?item p:P136 ?statement.
    ?statement ps:P136 ?genre.


    # Ensure that these statements have references
    FILTER EXISTS { ?statement prov:wasDerivedFrom ?reference. }
  }
}
```

#### Wikidata requirements

- To get the musibrainz id of the artist we use : https://www.wikidata.org/wiki/P434
- To get the artist name we use the english label

#### Import

get_or_create_artists_credits_from_musicbrainz

### Frontend behavior
